PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavGrid.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Variables
NavGrid.hpp File Reference
`#include "NavPoint.hpp"`
`#include "Rasterizer.hpp"`

Go to the source code of this file.

## Data Structures
struct | NavSpacings
| This struct stores the spacing requirements the NavGrid is/should be prepared for. More...
struct | AStarCosts
class | NavGrid
| The grid-representation of the board. More...

## Variables
constexpr const bool | CanSafelyEraseOverlappingSegments = false

## Variable Documentation

## ◆ CanSafelyEraseOverlappingSegments

const bool CanSafelyEraseOverlappingSegments = false
| constexpr

If rasterizing a path only increases the KO counts by 1 for each NavPoint instead of by N when N segments/joints cover the same NavPoint, then we cannot safely erase individual segments without screwing up overlap regions.